Module command_builder

Module command_builder 

Build command strings for different agent tools

Structs

AgentCommandOptions
Agent command build options

Functions

build_agent_command
Build the command for executing an agent
build_docker_stop_command
Build stop command for docker containers
build_piped_command
Build stdin piping command for tools that accept input via stdin
build_screen_stop_command
Build stop command for screen sessions
read_only_unsupported_error
Build the standard error for tools without enforceable read-only mode.
supports_read_only
Check whether a tool has an enforceable native read-only/planning mode.