AgentOptions

Struct AgentOptions 

pub struct AgentOptions {
Show 24 fields pub tool: String, pub working_directory: String, pub prompt: Option<String>, pub prompt_file: Option<String>, pub system_prompt: Option<String>, pub append_system_prompt: Option<String>, pub model: Option<String>, pub fallback_model: Option<String>, pub isolation: String, pub screen_name: Option<String>, pub container_name: Option<String>, pub json: bool, pub resume: Option<String>, pub verbose: bool, pub replay_user_messages: bool, pub session_id: Option<String>, pub fork_session: bool, pub read_only: bool, pub plan_only: bool, pub approve_each: bool, pub executable: Option<String>, pub extra_args: Vec<String>, pub extra_env: Vec<(String, String)>, pub skip_default_safety_flags: bool,
}
Agent options for creating a controller

Fields

tool: String

CLI tool to use (e.g., ‘claude’, ‘codex’, ‘opencode’, ‘agent’, ‘qwen’, ‘gemini’)

working_directory: String

Working directory for the agent

prompt: Option<String>

Prompt for the agent

prompt_file: Option<String>

File containing prompt input for stdin-based tools

system_prompt: Option<String>

System prompt for the agent

append_system_prompt: Option<String>

Append to the default system prompt (tool-specific)

model: Option<String>

Model to use (tool-specific)

fallback_model: Option<String>

Fallback model to use when the primary model is overloaded (tool-specific)

isolation: String

Isolation mode: ‘none’, ‘screen’, ‘docker’

screen_name: Option<String>

Screen session name (for screen isolation)

container_name: Option<String>

Container name (for docker isolation)

json: bool

Enable JSON output mode

resume: Option<String>

Resume a previous session (tool-specific)

verbose: bool

Enable verbose output (tool-specific)

replay_user_messages: bool

Re-emit user messages in streaming output (tool-specific)

session_id: Option<String>

Use a specific session ID (tool-specific)

fork_session: bool

Fork a resumed session into a new session (tool-specific)

read_only: bool

Enforce native read-only/planning mode

plan_only: bool

Enforce native planning mode (where the tool distinguishes it)

approve_each: bool

Approve each mutating command (ask mode), relayed over the tool’s native per-command JSON permission protocol (only claude and agent)

executable: Option<String>

Override the tool executable path/name

extra_args: Vec<String>

Extra raw arguments appended after typed tool arguments

extra_env: Vec<(String, String)>

Extra environment variables applied to the tool executable

skip_default_safety_flags: bool

Do not add default autonomous safety bypass flags