Build command strings for different agent tools
Structs
- Agent
Command Options - Agent command build options
Functions
- build_
agent_ command - Build the command for executing an agent
- build_
docker_ stop_ command - Build stop command for docker containers
- build_
piped_ command - Build stdin piping command for tools that accept input via stdin
- build_
screen_ stop_ command - Build stop command for screen sessions
- read_
only_ unsupported_ error - Build the standard error for tools without enforceable read-only mode.
- supports_
read_ only - Check whether a tool has an enforceable native read-only/planning mode.